NAME
Dist::Zilla::Plugin::IRC - Add a IRC channel resource to your dist
VERSION
version 0.001
SYNOPSIS
[IRC]
channel = distzilla
DESCRIPTION
This plugin facilitates adding a link to an IRC channel to the resources.
ATTRIBUTES
host
The hostname of the IRC channel.
network
The network that is used, if any. Valid values include perl (the default), libera, freenode and oftc
This is used to give host a default value, and is ignored otherwise.
channel
The name of the irc channel, this is mandatory for obvious reasons.
AUTHOR
Leon Timmermans <fawaka@gmail.com>
COPYRIGHT AND LICENSE
This software is copyright (c) 2026 by Leon Timmermans.
This is free software; you can redistribute it and/or modify it under the same terms as the Perl 5 programming language system itself.